@@ -44,6 +44,7 @@ class MsgFields(ConstantDict):
     CIDR = "cidr"
     COUNTRY_CODE = "cc"
     DOMAIN = "domain"
+    EXTERNAL_URL_SET = "exturlset"
     FILE_PACK = "filepack"
     GEOIP = "geoip"
     HOSTNAME = "hostname"
@@ -75,9 +76,11 @@ class MsgFields(ConstantDict):
     PHYSICAL_ADDRESS = "phyaddr"
     SCREENSHOT = "screenshot"
     SPIDER = "spider"
+    SPIDER_TIMEOUT = "spidertimeout"
     STATUS = "status"
     URL = "url"
     URL_CONTENT = "urlcontent"
+    URL_SPIDER_CONTENT = "urlspidercontent"
     WEB_FINGERPRINTS = "webfingerprints"
     WHOIS = "whois"
     WHOIS_RAW = "raw"
@@ -104,6 +107,8 @@ class MsgFields(ConstantDict):
     TASKS_ASNIP = "asnip_task"
     TASKS_GEOIP = "geoip_task"
     TASKS_HTTP_STATUS = "http_status_task"
+    TASKS_HTTP_GET = "http_get_task"
+    TASKS_HTTP_SPIDER = "http_spider_task"
     TASKS_RESOLVER = "resolver_task"
     TASKS_WEB_FINGERPRINT = "web_fingerprint_task"
     TASKS_OS_FINGERPRINT = "os_fingerprint_task"
@@ -114,9 +119,12 @@ class MsgValues(ConstantDict):
     HTTP_STATUS_NONCONNECT = -1
     HTTP_CONTENT_FILE = "content"
     HTTP_HEADERS_FILE = "headers"
+    HTTP_SPIDER_FILES = "spiderfiles"
 
     NMAP_STATUS_UP = "up"
 
+    URL_MANIFEST = "urlmani"
+
 
 class MsgErrs(ConstantDict):
     FILE_IO_ERROR = "FILE_IO_ERROR::{0}"
@@ -141,4 +149,5 @@ class MsgErrs(ConstantDict):
 
     URL_INVALID = "URL_INVALID::{0}"
     URL_TIMEOUT = "URL_TIMEOUT::{0}"
+    URL_SPIDER_TIMEOUT = "URL_SPIDER_TIMEOUT::{0}"
     URL_CONN_ERROR = "URL_CONN_ERROR::{0}"
