@@ -146,6 +146,21 @@ UrlcontentSchema = build_schema({
     }
 })
 
+UrlspidercontentSchema = build_schema({
+    "properties": {
+        F.HTTP_STATUS: {"type": ["number", "null"]},
+        F.FILE_PACK: {"type": ["string", "null"]},
+        F.SPIDER_TIMEOUT: {"type": "boolean"},
+        F.EXTERNAL_URL_SET: {
+            "type": "array",
+            "items": {
+                "type": ["string", "null"],
+            }
+        },
+        # F.IP: {"type": ["string", "null"]},
+    }
+})
+
 IpSingleSchema = build_schema({
     "properties": {
         F.IP: {
